@@ -3,9 +3,11 @@ from idiopidae.runtime import Composer
 from ordereddict import OrderedDict
 from pygments.formatters import get_formatter_for_filename
 from pygments.lexers import get_lexer_for_filename
+from pygments.lexers import get_lexer_by_name
 from pygments.lexers.agile import PythonConsoleLexer
 from pygments.lexers.agile import RubyConsoleLexer
 from pygments.lexers.web import JavascriptLexer
+from pygments.lexers.web import PhpLexer
 import idiopidae.parser
 
 class IdioHandler(DexyHandler):
@@ -23,17 +25,25 @@ class IdioHandler(DexyHandler):
 
         ext = self.artifact.input_ext
         name = "input_text%s" % ext
-        # List any file extensions which don't map neatly to lexers.
-        if ext == '.pycon':
+
+        if self.doc.args.has_key('pyg-lexer'):
+            lexer = get_lexer_by_name(self.doc.args['pyg-lexer'])
+        elif ext == '.pycon':
             lexer = PythonConsoleLexer()
         elif ext == '.rbcon':
             lexer = RubyConsoleLexer()
         elif ext in ('.json', '.dexy'):
             lexer = JavascriptLexer()
+        elif ext in ('.php'):
+            # If we are using idio, then our code will be in sections so we
+            # need to start inline with PHP. To avoid this, use pyg instead of
+            # idio. (Eventually should be able to specify lexer + options in config.)
+            lexer = PhpLexer(startinline=True)
         else:
             lexer = get_lexer_for_filename(name)
+
         formatter = get_formatter_for_filename(self.artifact.filename(),
-                                               lineanchors='l')
+                lineanchors='l')
         output_dict = OrderedDict()
 
         for i, s in enumerate(builder.sections):
